@@ -18,6 +18,8 @@ import glob
 import traceback
 
 from monty.io import zopen
+from monty.json import jsanitize
+from monty.os.path import which
 
 import numpy as np
 
@@ -26,9 +28,10 @@ from pymatgen.core.structure import Structure
 from pymatgen.core.operations import SymmOp
 from pymatgen.electronic_structure.bandstructure import BandStructureSymmLine
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
-from pymatgen.io.vasp import BSVasprun, Vasprun, Outcar, Locpot
+from pymatgen.io.vasp import BSVasprun, Vasprun, Outcar, Locpot, Chgcar
 from pymatgen.io.vasp.inputs import Poscar, Potcar, Incar, Kpoints
 from pymatgen.apps.borg.hive import AbstractDrone
+from pymatgen.command_line.bader_caller import bader_analysis_from_path
 
 from atomate.utils.utils import get_uri
 
@@ -42,6 +45,7 @@ __version__ = "0.1.0"
 
 logger = get_logger(__name__)
 
+bader_exe_exists = which("bader") or which("bader.exe")
 
 class VaspDrone(AbstractDrone):
     """
@@ -73,12 +77,13 @@ class VaspDrone(AbstractDrone):
             'has_vasp_completed'
         },
         "analysis": {'delta_volume_as_percent', 'delta_volume', 'max_force',
-                     'errors',
-                     'warnings'}
+                     'errors', 'warnings'}
+
     }
 
     def __init__(self, runs=None, parse_dos="auto", bandstructure_mode="auto",
-                 parse_locpot=True, additional_fields=None, use_full_uri=True):
+                 parse_locpot=True, additional_fields=None, use_full_uri=True,
+                 parse_bader=bader_exe_exists, parse_chgcar=False, parse_aeccar=False):
         """
         Initialize a Vasp drone to parse vasp outputs
         Args:
@@ -98,13 +103,20 @@ class VaspDrone(AbstractDrone):
             parse_locpot (bool): Parses the LOCPOT file and saves the 3 axis averages
             additional_fields (dict): dictionary of additional fields to add to output document
             use_full_uri (bool): converts the directory path to the full URI path
+            parse_bader (bool): Run and parse Bader charge data. Defaults to True if Bader is present
+            parse_chgcar (bool): Run and parse CHGCAR file
+            parse_aeccar (bool): Run and parse AECCAR0 and AECCAR2 files
         """
         self.parse_dos = parse_dos
         self.additional_fields = additional_fields or {}
         self.use_full_uri = use_full_uri
-        self.runs = runs or ["precondition"] + ["relax" + str(i + 1) for i in range(9)]  # can't auto-detect: path unknown
+        self.runs = runs or ["precondition"] + ["relax" + str(i + 1)
+                                                for i in range(9)]  # can't auto-detect: path unknown
         self.bandstructure_mode = bandstructure_mode
         self.parse_locpot = parse_locpot
+        self.parse_bader = parse_bader
+        self.parse_chgcar = parse_chgcar
+        self.parse_aeccar = parse_aeccar
 
     def assimilate(self, path):
         """
@@ -174,7 +186,7 @@ class VaspDrone(AbstractDrone):
         try:
             # basic properties, incl. calcs_reversed and run_stats
             fullpath = os.path.abspath(dir_name)
-            d = {k: v for k, v in self.additional_fields.items()}
+            d = jsanitize(self.additional_fields, strict=True)
             d["schema"] = {"code": "atomate", "version": VaspDrone.__version__}
             d["dir_name"] = fullpath
             d["calcs_reversed"] = [self.process_vasprun(dir_name, taskname, filename)
@@ -294,7 +306,7 @@ class VaspDrone(AbstractDrone):
 
             self.set_analysis(d)
 
-            d["last_updated"] = datetime.datetime.today()
+            d["last_updated"] = datetime.datetime.utcnow()
             return d
 
         except Exception:
@@ -337,43 +349,21 @@ class VaspDrone(AbstractDrone):
         for k, v in {"energy": "final_energy", "energy_per_atom": "final_energy_per_atom"}.items():
             d["output"][k] = d["output"].pop(v)
 
-        # parse dos if forced to or auto mode set and  0 ionic steps were performed -> static calculation
-        if self.parse_dos == True or (str(self.parse_dos).lower() == "auto" and vrun.incar.get("NSW", 1) == 0):
-            try:
-                d["dos"] = vrun.complete_dos.as_dict()
-            except:
-                raise ValueError("No valid dos data exist in {}.".format(dir_name))
+        # Process bandstructure and DOS
+        if self.bandstructure_mode != False:
+            bs = self.process_bandstructure(vrun)
+            if bs:
+                d["bandstructure"] = bs
 
-        # Band structure parsing logic
-        if str(self.bandstructure_mode).lower() == "auto":
-            # if line mode nscf
-            if vrun.incar.get("ICHARG", 0) > 10 and vrun.kpoints.num_kpts > 0:
-                bs_vrun = BSVasprun(vasprun_file, parse_projected_eigen=True)
-                bs = bs_vrun.get_band_structure(line_mode=True)
-            # else if nscf
-            elif vrun.incar.get("ICHARG", 0) > 10:
-                bs_vrun = BSVasprun(vasprun_file, parse_projected_eigen=True)
-                bs = bs_vrun.get_band_structure()
-            # else just regular calculation
-            else:
-                bs = vrun.get_band_structure()
-
-            # only save the bandstructure if not moving ions
-            if vrun.incar["NSW"] == 0:
-                d["bandstructure"] = bs.as_dict()
-
-        # legacy line/True behavior for bandstructure_mode
-        elif self.bandstructure_mode:
-            bs_vrun = BSVasprun(vasprun_file, parse_projected_eigen=True)
-            bs = bs_vrun.get_band_structure(line_mode=(str(self.bandstructure_mode).lower() == "line"))
-            d["bandstructure"] = bs.as_dict()
-        # parse bandstructure for vbm/cbm/bandgap but don't save
-        else:
-            bs = vrun.get_band_structure()
+        if self.parse_dos != False:
+            dos = self.process_dos(vrun)
+            if dos:
+                d["dos"] = dos
 
         # Parse electronic information if possible.
         # For certain optimizers this is broken and we don't get an efermi resulting in the bandstructure
         try:
+            bs = vrun.get_band_structure()
             bs_gap = bs.get_band_gap()
             d["output"]["vbm"] = bs.get_vbm()["energy"]
             d["output"]["cbm"] = bs.get_cbm()["energy"]
@@ -405,13 +395,91 @@ class VaspDrone(AbstractDrone):
             locpot = Locpot.from_file(os.path.join(dir_name, d["output_file_paths"]["locpot"]))
             d["output"]["locpot"] = {i: locpot.get_average_along_axis(i) for i in range(3)}
 
+        if self.parse_chgcar != False:
+            # parse CHGCAR file only for static calculations
+            # TODO require static run later
+            # if self.parse_chgcar == True and vrun.incar.get("NSW", 0) < 1:
+            try:
+                chgcar = self.process_chgcar(os.path.join(dir_name, d["output_file_paths"]["chgcar"]))
+            except:
+                raise ValueError("No valid charge data exist")
+            d["chgcar"] = chgcar
+
+        if self.parse_aeccar != False:
+            try:
+                chgcar = self.process_chgcar(os.path.join(dir_name, d["output_file_paths"]["aeccar0"]))
+            except:
+                raise ValueError("No valid charge data exist")
+            d["aeccar0"] = chgcar
+            try:
+                chgcar = self.process_chgcar(os.path.join(dir_name, d["output_file_paths"]["aeccar2"]))
+            except:
+                raise ValueError("No valid charge data exist")
+            d["aeccar2"] = chgcar
+
         # parse force constants
         if hasattr(vrun, "force_constants"):
             d["output"]["force_constants"] = vrun.force_constants.tolist()
             d["output"]["normalmode_eigenvals"] = vrun.normalmode_eigenvals.tolist()
             d["output"]["normalmode_eigenvecs"] = vrun.normalmode_eigenvecs.tolist()
+
+        # Try and perform bader
+        if self.parse_bader:
+            try:
+                bader = bader_analysis_from_path(dir_name, suffix=".{}".format(taskname))
+            except Exception as e:
+                bader = "Bader analysis failed: {}".format(e)
+            d["bader"] = bader
+
         return d
 
+    @classmethod
+    def process_chgcar(cls, chg_file):
+        try:
+            chgcar = Chgcar.from_file(chg_file)
+        except IOError:
+            raise ValueError("Unable to open CHGCAR/AECCAR file" )
+        return chgcar
+
+    def process_bandstructure(self, vrun):
+
+        vasprun_file = vrun.filename
+        # Band structure parsing logic
+        if str(self.bandstructure_mode).lower() == "auto":
+            # if NSCF calculation
+            if vrun.incar.get("ICHARG", 0) > 10:
+                bs_vrun = BSVasprun(vasprun_file, parse_projected_eigen=True)
+                try:
+                    # Try parsing line mode
+                    bs = bs_vrun.get_band_structure(line_mode=True)
+                except:
+                    # Just treat as a regular calculation
+                    bs = bs_vrun.get_band_structure()
+            # else just regular calculation
+            else:
+                bs_vrun = BSVasprun(vasprun_file, parse_projected_eigen=False)
+                bs = bs_vrun.get_band_structure()
+
+            # only save the bandstructure if not moving ions
+            if vrun.incar.get("NSW", 0) <= 1:
+                return bs.as_dict()
+
+        # legacy line/True behavior for bandstructure_mode
+        elif self.bandstructure_mode:
+            bs_vrun = BSVasprun(vasprun_file, parse_projected_eigen=True)
+            bs = bs_vrun.get_band_structure(line_mode=(str(self.bandstructure_mode).lower() == "line"))
+            return bs.as_dict()
+
+        return None
+
+    def process_dos(self, vrun):
+        # parse dos if forced to or auto mode set and  0 ionic steps were performed -> static calculation and not DFPT
+        if self.parse_dos == True or (str(self.parse_dos).lower() == "auto" and vrun.incar.get("NSW", 0) < 1):
+            try:
+                return vrun.complete_dos.as_dict()
+            except:
+                raise ValueError("No valid dos data exist")
+
     def process_raw_data(self, dir_name, taskname="standard"):
         """
         It is useful to store what raw data has been calculated
@@ -452,7 +520,8 @@ class VaspDrone(AbstractDrone):
         max_force = None
         calc = d["calcs_reversed"][0]
         if d["state"] == "successful" and calc["input"]["parameters"].get("NSW", 0) > 0:
-            # handle the max force and max force error
+
+            # calculate max forces
             forces = np.array(calc['output']['ionic_steps'][-1]['forces'])
             # account for selective dynamics
             final_structure = Structure.from_dict(calc['output']['structure'])
@@ -460,9 +529,6 @@ class VaspDrone(AbstractDrone):
             if sdyn:
                 forces[np.logical_not(sdyn)] = 0
             max_force = max(np.linalg.norm(forces, axis=1))
-            if max_force > max_force_threshold:
-                error_msgs.append("Final max force exceeds {} eV".format(max_force_threshold))
-                d["state"] = "error"
 
             s = Structure.from_dict(d["output"]["structure"])
             if not s.is_valid():
