@@ -21,7 +21,7 @@ from pymatgen.core.structure import Structure
 from pymatgen.alchemy.materials import TransformedStructure
 from pymatgen.alchemy.transmuters import StandardTransmuter
 from pymatgen.io.vasp import Incar, Poscar, Potcar, PotcarSingle
-from pymatgen.io.vasp.sets import MPStaticSet, MPNonSCFSet, MPSOCSet, MPHSEBSSet
+from pymatgen.io.vasp.sets import MPStaticSet, MPNonSCFSet, MPSOCSet, MPHSEBSSet, MPNMRSet
 
 from atomate.utils.utils import env_chk, load_class
 from atomate.vasp.firetasks.glue_tasks import GetInterpolatedPOSCAR
@@ -166,7 +166,10 @@ class ModifyIncar(FiretaskBase):
 
         if incar_multiply:
             for k in incar_multiply:
-                incar[k] = incar[k] * incar_multiply[k]
+                if hasattr(incar[k], '__iter__'):  # is list-like
+                    incar[k] = list(np.multiply(incar[k], incar_multiply[k]))
+                else:
+                    incar[k] = incar[k] * incar_multiply[k]
 
         if incar_dictmod:
             apply_mod(incar_dictmod, incar)
@@ -323,16 +326,13 @@ class WriteVaspSOCFromPrev(FiretaskBase):
     Writes input files for a spinorbit coupling calculation.
 
     Required params:
-        prev_calc_dir: path to previous calculation
         magmom (list): magnetic moment values for each site in the structure.
         saxis (list): magnetic field direction
 
-    Optional params:
-        (none)
     """
     required_params = ["magmom", "saxis"]
 
-    optional_params = ["copy_chgcar", "nbands_factor", "reciprocal_density", "small_gap_multiply",
+    optional_params = ["prev_calc_dir", "copy_chgcar", "nbands_factor", "reciprocal_density", "small_gap_multiply",
                        "standardize", "sym_prec", "international_monoclinic", "other_params"]
 
     def run_task(self, fw_spec):
@@ -355,6 +355,31 @@ class WriteVaspSOCFromPrev(FiretaskBase):
         vis.write_input(".")
 
 
+@explicit_serialize
+class WriteVaspNMRFromPrev(FiretaskBase):
+    """
+    Writes input files for a NMR calculation
+
+    Optional params::
+        prev_calc_dir: path to previous calculation, else current directory
+        mode (str): the NMR calculation type: cs or efg, default is cs
+        isotopes (list): list of isotopes to include, default is to include the
+                         lowest mass quadrupolar isotope for all applicable elements
+        reciprocol_density (int): the reciprocol density for the kpoint mesh, defaults to 100
+        other_aprams (dict) : any other params passsed to MPNMRSet as a dictionary
+    """
+    optional_params = ["mode", "isotopes", "reciprocal_density", "other_params"]
+
+    def run_task(self, fw_spec):
+        vis = MPNMRSet.from_prev_calc(
+            prev_calc_dir=self.get("prev_calc_dir", "."),
+            mode=self.get("mode", "cs"),
+            isotopes=self.get("isotopes", None),
+            reciprocal_density=self.get("reciprocal_density", 100),
+            **self.get("other_params", {}))
+        vis.write_input(".")
+
+
 @explicit_serialize
 class WriteTransmutedStructureIOSet(FiretaskBase):
     """
